@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: upload-item.cpp 666 2005-09-09 01:07:32Z svn $
+ * $Id: upload-item.cpp 1007 2006-03-14 14:23:17Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -73,20 +73,24 @@ void Init_UploadItem(void)
  *****************************************************************************/
 VALUE list_total_file_size(VALUE self)
 {
-    VALUE total_size;
+    VALUE total_size_array;
+    apr_uint64_t total_size_num;
+    VALUE total_size_str;
     apr_pool_t *pool;
 
-    total_size = rb_funcall(self, rb_intern("total_file_size_impl"), 0);
+    total_size_array = rb_funcall(self, rb_intern("total_file_size_impl"), 0);
 
     if (apr_pool_create(&pool, NULL) != APR_SUCCESS) {
         exit(EXIT_FAILURE); // :-<
     }
 
-    total_size = rb_str_new2(size_str(pool, NUM2UINT(total_size)));
+    total_size_num = (static_cast<apr_uint64_t>(NUM2UINT(rb_ary_shift(total_size_array))) << 32) |
+        static_cast<apr_uint64_t>(NUM2UINT(rb_ary_shift(total_size_array)));
+    total_size_str = rb_str_new2(size_str(pool, total_size_num));
 
     apr_pool_clear(pool);
 
-    return total_size;
+    return total_size_str;
 }
 
 
@@ -135,7 +139,7 @@ VALUE reader_read(VALUE self, VALUE file_path)
     }
 
     try {
-        header = impl->instance->read(StringValueCStr(file_path), &file, pool);
+        header = impl->instance->read(pool, StringValueCStr(file_path), &file);
     } catch(const char *message) {
         apr_pool_clear(pool);
         rb_raise(rb_eval_string("Exception"), "%s", message);
