@@ -27,68 +27,103 @@
  * $Id: TemplateExecutor.h 160 2005-03-19 18:17:33Z svn $
  *****************************************************************************/
 
-#ifndef RSSVIEW_H
-#define RSSVIEW_H
+#ifndef RSS_VIEW_H
+#define RSS_VIEW_H
 
-#ifdef HAVE_CONFIG_H
-#include "mod_uploader_config.h"
-#endif
-
-#include "PageView.h"
-
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#include "httpd.h"
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
+#include "UploadItemList.h"
 
 #include "apr_pools.h"
 #include "apr_time.h"
 
 #include <cstdlib>
 
+#ifdef HAVE_CONFIG_H
+#include "mod_uploader_config.h"
+#endif
+
 using namespace std;
 
 /**
  * @brief RSS Ϥ륯饹
  */
-class RssView : public PageView
+template<class ResponseWriterClass>
+class RssView
 {
 public:
+    /** ڡ Content-type */
     static const char content_type[];
-    static const char image_type_prefix[];
 
-    void exec(apr_pool_t *pool, request_rec *request, const char *base_url,
-              UploadItemList *item_list, apr_size_t per_page_item_number);
+    /**
+     * 󥹥ȥ饯Ǥ
+     *
+     * @param[in] pool ס
+     * @param[in] writer 쥹ݥ󥹤񤭽Ф֥ȡ
+     */
+    RssView(apr_pool_t *pool, ResponseWriterClass& writer);
+
+    /**
+     * ڡϤޤ
+     *
+
+     * @param[in] base_url ȥåץڡ URL
+     * @param[in] per_page_item_number ڡɽ륢ƥ
+     * @param[in] item_list åץɥƥΥꥹ
+     */
+    void exec(const char *base_url, apr_size_t per_page_item_number,
+              UploadItemList *item_list);
 private:
+    /** ɽκĹ */
     static const apr_size_t MAX_TIME_LENGTH;
+    /** ɽΥեޥå */
     static const char TIME_FORMAT[];
+    /** ॾΥեå͡ʡhh:mm */
     static const apr_size_t TIME_ZONE_OFFSET;
 
     typedef UploadItemList::item_info item_info;
+    /**
+     * ϥϥɥ롥
+     */
     typedef struct Handle {
-        apr_pool_t * const pool;
-        request_rec * const request;
+        /** ȥåץڡ URL */
         const char * const base_url;
 
-        Handle(apr_pool_t *pool, request_rec *request, const char *base_url)
-            : pool(pool),
-              request(request),
-              base_url(base_url)
+        Handle(const char *base_url)
+            : base_url(base_url)
         {
 
         }
     } handle;
 
-    static void print(handle *h, item_info *item);
-    static void print(handle *h, const char *str);
+    /**
+     * åץɥƥϤޤ
+     *
+     * @param[in] h ϥϥɥ
+     * @param[in] item åץɥƥ
+     */
+    void print(handle *h, item_info *item);
+    /**
+     * ʸϤޤ
+     *
+     * @param[in] h ϥϥɥ
+     * @param[in] str ʸ
+     */
+    void print(handle *h, const char *str);
+    /**
+     * ʸϤޤ
+     *
+     * @param[in] pool ס
+     * @param[in] time 
+     * @return եޥåȤ
+     */
     static const char *time_str(apr_pool_t *pool, apr_time_t time);
+
+    RssView(const RssView&);
+    RssView &operator=(const RssView&);
+
+    /** ס */
+    apr_pool_t *pool_;
+    /** 쥹ݥ󥹤񤭽Ф֥ */
+    ResponseWriterClass writer_;
 };
 
 #endif
