@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 899 2005-10-24 17:25:34Z svn $
+ * $Id: UploadItem.h 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -75,7 +75,7 @@ public:
                 char        identifier[MAX_IDENTIFIER_LENGTH];
                 char        version[MAX_VERSION_LENGTH];
                 union {
-                    apr_size_t  file_size;
+                    apr_uint64_t file_size;
                     char        dummy_file_size[16];
                 };
                 union {
@@ -167,7 +167,7 @@ private:
     static const char FILE_DIGEST_KEY[];
     static const char TIME_KEY[];
 
-    static const apr_size_t TIME_ZONE_OFFSET;
+    static const apr_int32_t TIME_ZONE_OFFSET;
     static const apr_size_t MAX_TIME_LENGTH;
     static const char TIME_FORMAT[];
 
