@@ -24,11 +24,12 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MessageDigest5.cpp 895 2005-10-23 18:50:50Z svn $
+ * $Id: MessageDigest5.cpp 1008 2006-03-14 20:04:20Z svn $
  *****************************************************************************/
 
 #include "MessageDigest5.h"
 #include "Misc.h"
+#include "Resource.h"
 
 #define APR_WANT_MEMFUNC
 #define APR_WANT_STDIO
@@ -72,7 +73,7 @@ void MessageDigest5::update(const apr_byte_t *input, apr_size_t size)
 
 #ifdef DEBUG
     if (is_finish_) {
-        throw "Ǥ";
+        throw OPERATION_INVALID;
     }
 #endif
 
@@ -110,7 +111,7 @@ void MessageDigest5::finish()
 
 #ifdef DEBUG
     if (is_finish_) {
-        throw "Ǥ";
+        throw OPERATION_INVALID;
     }
 #endif
 
@@ -132,7 +133,7 @@ const char *MessageDigest5::c_str()
 {
 #ifdef DEBUG
     if (!is_finish_) {
-        throw "Ǥ";
+        throw OPERATION_INVALID;
     }
 #endif
 
@@ -213,11 +214,11 @@ void MessageDigest5::byte2int(const apr_byte_t *bytes, apr_uint32_t *ints)
     }
 }
 
-void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t len, apr_byte_t *bytes)
+void MessageDigest5::int2byte(const apr_uint32_t *ints, apr_size_t length, apr_byte_t *bytes)
 {
     apr_size_t i;
 
-    for (i = 0; i < len; ++i) {
+    for (i = 0; i < length; ++i) {
         bytes[i*4    ] = (ints[i]      ) & 0xff;
         bytes[i*4 + 1] = (ints[i] >>  8) & 0xff;
         bytes[i*4 + 2] = (ints[i] >> 16) & 0xff;
@@ -312,12 +313,25 @@ void MessageDigest5::create_digest()
 {
     int2byte(state_, 4, digest_bytes_);
 
-    sprintf(digest_str_,
-            "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
-            digest_bytes_[ 0], digest_bytes_[ 1], digest_bytes_[ 2], digest_bytes_[ 3],
-            digest_bytes_[ 4], digest_bytes_[ 5], digest_bytes_[ 6], digest_bytes_[ 7],
-            digest_bytes_[ 8], digest_bytes_[ 9], digest_bytes_[10], digest_bytes_[11],
-            digest_bytes_[12], digest_bytes_[13], digest_bytes_[14], digest_bytes_[15]);
+#ifdef _MSC_VER
+    sprintf_s(digest_str_, sizeof(digest_str_),
+              "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
+              digest_bytes_[ 0], digest_bytes_[ 1], digest_bytes_[ 2],
+              digest_bytes_[ 3], digest_bytes_[ 4], digest_bytes_[ 5],
+              digest_bytes_[ 6], digest_bytes_[ 7], digest_bytes_[ 8],
+              digest_bytes_[ 9], digest_bytes_[10], digest_bytes_[11],
+              digest_bytes_[12], digest_bytes_[13], digest_bytes_[14],
+              digest_bytes_[15]);
+#else
+    snprintf(digest_str_, sizeof(digest_str_)-1,
+             "%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
+             digest_bytes_[ 0], digest_bytes_[ 1], digest_bytes_[ 2],
+             digest_bytes_[ 3], digest_bytes_[ 4], digest_bytes_[ 5],
+             digest_bytes_[ 6], digest_bytes_[ 7], digest_bytes_[ 8],
+             digest_bytes_[ 9], digest_bytes_[10], digest_bytes_[11],
+             digest_bytes_[12], digest_bytes_[13], digest_bytes_[14],
+             digest_bytes_[15]);
+#endif
 }
 
 
