@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 914 2005-11-17 15:07:03Z svn $
+ * $Id: UploaderConfig.cpp 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -43,7 +43,7 @@
 
 const apr_uint64_t UploaderConfig::TOTAL_FILE_SIZE_LIMIT= 1*1024*1024*1024;
 const apr_size_t UploaderConfig::TOTAL_FILE_NUMBER_LIMIT= 1000;
-const apr_size_t UploaderConfig::MAX_FORM_FILE_SIZE     = 100*1024*1024;
+const apr_uint64_t UploaderConfig::MAX_FORM_FILE_SIZE   = 100*1024*1024;
 const apr_size_t UploaderConfig::MAX_FORM_TEXT_SIZE     = 1024;
 const apr_size_t UploaderConfig::MAX_FORM_ITEM_NUMBER   = 5;
 const apr_size_t UploaderConfig::PER_PAGE_ITEM_NUMBER   = 50;
