@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: lighttpd_handler.cpp 914 2005-11-17 15:07:03Z svn $
+ * $Id: lighttpd_handler.cpp 1003 2006-03-14 13:52:47Z svn $
  *****************************************************************************/
 
 #define __STDC_CONSTANT_MACROS
@@ -137,7 +137,7 @@ static apr_size_t get_page(connection *con)
     return (con->uri.query->used == 0) ? 1 : get_page(con->uri.query->ptr);
 }
 
-static apr_size_t get_upload_id(connection *con)
+static apr_uint32_t get_upload_id(connection *con)
 {
     return (con->uri.query->used == 0) ? 1 : get_upload_id(con->uri.query->ptr);
 }
@@ -344,7 +344,7 @@ static handler_t upload_init(server *srv, connection *con, uconfig *config,
                              apr_pool_t *pool, const char *arg, plugin_data *p)
 {
     const char *address;
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
 
     if (con->request.http_method != HTTP_METHOD_POST) {
         return handler_finish(con, 400);
@@ -373,7 +373,7 @@ static handler_t upload(server *srv, connection *con, uconfig *config,
                         buffer *res)
 {
     const char *address;
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     pprogress *progress;
 
     address = con->dst_addr_buf->ptr;
@@ -440,7 +440,7 @@ static handler_t progress_data(server *srv, connection *con, uconfig *config,
                                apr_pool_t *pool, const char *arg,
                                plugin_data *p, buffer *res)
 {
-    apr_size_t upload_id;
+    apr_uint32_t upload_id;
     pprogress *progress;
     const char *progress_str;
     connection *post_con;
@@ -463,12 +463,12 @@ static handler_t progress_data(server *srv, connection *con, uconfig *config,
     post_con = reinterpret_cast<connection *>(progress->data);
 
     if (progress->total_size != 0) {
-        progress_str = apr_psprintf(pool, "s %" APR_SIZE_T_FMT " %" APR_SIZE_T_FMT,
+        progress_str = apr_psprintf(pool, "s %" APR_UINT64_T_FMT " %" APR_UINT64_T_FMT,
                                     progress->total_size, progress->read_size);
     } else {
-        progress_str = apr_psprintf(pool, "s %" APR_SIZE_T_FMT " %" APR_SIZE_T_FMT,
-                                    static_cast<apr_size_t>(post_con->request.content_length),
-                                    static_cast<apr_size_t>(post_con->request_content_queue->bytes_in));
+        progress_str = apr_psprintf(pool, "s %" APR_UINT64_T_FMT " %" APR_UINT64_T_FMT,
+                                    static_cast<apr_uint64_t>(post_con->request.content_length),
+                                    static_cast<apr_uint64_t>(post_con->request_content_queue->bytes_in));
     }
 
     buffer_append_string(res, progress_str);
