@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader_apache.cpp 1066 2006-05-15 14:02:20Z svn $
+ * $Id: mod_uploader_apache.cpp 1071 2006-05-21 05:31:48Z svn $
  *****************************************************************************/
 
 /**
@@ -113,9 +113,6 @@ static int uploader_handler(request_rec *r)
 {
     uconfig *config;
 
-    cerr << "CERR " << endl;
-    cout << "COUT " << endl;
-
     if (strcmp(r->handler, "uploader")) {
         return DECLINED;
     }
@@ -192,7 +189,6 @@ static apr_status_t create_lock(apr_pool_t *pool, apr_global_mutex_t **lock,
     if (status != APR_SUCCESS) {
         SERROR("Can not set permissions on global mutex (%s).", "NULL");
         SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
-
         return status;
     }
 #endif
@@ -226,15 +222,15 @@ static apr_status_t create_shm(apr_pool_t *pool, apr_shm_t **shm_data,
 }
 
 static apr_status_t attach_lock(apr_pool_t *pool, apr_global_mutex_t **lock,
-                                const char *file_path, server_rec *server)
+                                server_rec *server)
 {
     apr_status_t status;
     char error[MAX_ERROR_MESSAGE];
 
-    status = apr_global_mutex_child_init(lock, file_path, pool);
+    status = apr_global_mutex_child_init(lock, NULL, pool);
 
     if (status != APR_SUCCESS) {
-           SERROR("Can not attach to global mutex (%s).", file_path);
+           SERROR("Can not attach to global mutex (%s).", "NULL");
            SERROR("(%s)", apr_strerror(status, error, sizeof(error)));
 
            return status;
@@ -346,8 +342,7 @@ static void child_init_server(apr_pool_t *pool, server_rec *server)
 
     config = static_cast<sconfig *>(ap_get_module_config(server->module_config, &uploader_module));
 
-    if (attach_lock(pool, &(config->upload_lock), NULL,
-                    server)  != APR_SUCCESS) {
+    if (attach_lock(pool, &(config->upload_lock), server) != APR_SUCCESS) {
         return;
     }
 
@@ -377,14 +372,16 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
     apr_status_t status;
 
     apr_pool_userdata_get(&user_data, USER_DATA_KEY, s->process->pool);
+
     if (user_data == NULL) {
         apr_pool_userdata_set(reinterpret_cast<const void *>(1), USER_DATA_KEY,
                               apr_pool_cleanup_null, s->process->pool);
+
         return OK;
     }
 
     do {
-        status = post_config_server(plog, s);
+        status = post_config_server(pconf, s);
 
         if (status != OK) {
             return status;
@@ -463,9 +460,6 @@ static const command_rec uploader_cmds[] = {
     { NULL }
 };
 
-
-
-
 static void uploader_register_hooks(apr_pool_t *pool)
 {
     ap_hook_post_config(post_config, NULL, NULL, APR_HOOK_REALLY_FIRST);
